==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/ExternalNetworkPropertiesOptionAPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.ExternalNetworkPropertiesOptionAPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * option A properties object
 * @property mtu MTU to use for option A peering.
 * @property peerASN Peer ASN number.Example : 28
 * @property primaryIpv4Prefix IPv4 Address Prefix of CE-PE interconnect links. Example: 172.31.0.0/31. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
 * @property primaryIpv6Prefix IPv6 Address Prefix of CE-PE interconnect links. Example: 3FFE:FFFF:0:CD30::a0/126. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
 * @property secondaryIpv4Prefix Secondary IPv4 Address Prefix of CE-PE interconnect links. Example: 172.31.0.20/31. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
 * @property secondaryIpv6Prefix Secondary IPv6 Address Prefix of CE-PE interconnect links. Example: 3FFE:FFFF:0:CD30::a4/126. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
 * @property vlanId Vlan identifier. Example : 501
 */
public data class ExternalNetworkPropertiesOptionAPropertiesArgs(
    public val mtu: Output<Int>? = null,
    public val peerASN: Output<Int>,
    public val primaryIpv4Prefix: Output<String>? = null,
    public val primaryIpv6Prefix: Output<String>? = null,
    public val secondaryIpv4Prefix: Output<String>? = null,
    public val secondaryIpv6Prefix: Output<String>? = null,
    public val vlanId: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.ExternalNetworkPropertiesOptionAPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.ExternalNetworkPropertiesOptionAPropertiesArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.ExternalNetworkPropertiesOptionAPropertiesArgs.builder()
            .mtu(mtu?.applyValue({ args0 -> args0 }))
            .peerASN(peerASN.applyValue({ args0 -> args0 }))
            .primaryIpv4Prefix(primaryIpv4Prefix?.applyValue({ args0 -> args0 }))
            .primaryIpv6Prefix(primaryIpv6Prefix?.applyValue({ args0 -> args0 }))
            .secondaryIpv4Prefix(secondaryIpv4Prefix?.applyValue({ args0 -> args0 }))
            .secondaryIpv6Prefix(secondaryIpv6Prefix?.applyValue({ args0 -> args0 }))
            .vlanId(vlanId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExternalNetworkPropertiesOptionAPropertiesArgs].
 */
@PulumiTagMarker
public class ExternalNetworkPropertiesOptionAPropertiesArgsBuilder internal constructor() {
    private var mtu: Output<Int>? = null

    private var peerASN: Output<Int>? = null

    private var primaryIpv4Prefix: Output<String>? = null

    private var primaryIpv6Prefix: Output<String>? = null

    private var secondaryIpv4Prefix: Output<String>? = null

    private var secondaryIpv6Prefix: Output<String>? = null

    private var vlanId: Output<Int>? = null

    /**
     * @param value MTU to use for option A peering.
     */
    @JvmName("dkteljpgjalddoil")
    public suspend fun mtu(`value`: Output<Int>) {
        this.mtu = value
    }

    /**
     * @param value Peer ASN number.Example : 28
     */
    @JvmName("qkeulxngwfttuudo")
    public suspend fun peerASN(`value`: Output<Int>) {
        this.peerASN = value
    }

    /**
     * @param value IPv4 Address Prefix of CE-PE interconnect links. Example: 172.31.0.0/31. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("yqiadlqfukfeapxc")
    public suspend fun primaryIpv4Prefix(`value`: Output<String>) {
        this.primaryIpv4Prefix = value
    }

    /**
     * @param value IPv6 Address Prefix of CE-PE interconnect links. Example: 3FFE:FFFF:0:CD30::a0/126. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("dqhsnlyssnckngvh")
    public suspend fun primaryIpv6Prefix(`value`: Output<String>) {
        this.primaryIpv6Prefix = value
    }

    /**
     * @param value Secondary IPv4 Address Prefix of CE-PE interconnect links. Example: 172.31.0.20/31. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("ekltrhcsxiptfpnf")
    public suspend fun secondaryIpv4Prefix(`value`: Output<String>) {
        this.secondaryIpv4Prefix = value
    }

    /**
     * @param value Secondary IPv6 Address Prefix of CE-PE interconnect links. Example: 3FFE:FFFF:0:CD30::a4/126. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("rwlkdukthiofhvoq")
    public suspend fun secondaryIpv6Prefix(`value`: Output<String>) {
        this.secondaryIpv6Prefix = value
    }

    /**
     * @param value Vlan identifier. Example : 501
     */
    @JvmName("aqlvragrudxlaxta")
    public suspend fun vlanId(`value`: Output<Int>) {
        this.vlanId = value
    }

    /**
     * @param value MTU to use for option A peering.
     */
    @JvmName("dcahwldhyxaaabaw")
    public suspend fun mtu(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mtu = mapped
    }

    /**
     * @param value Peer ASN number.Example : 28
     */
    @JvmName("yylclctnihjyisdb")
    public suspend fun peerASN(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.peerASN = mapped
    }

    /**
     * @param value IPv4 Address Prefix of CE-PE interconnect links. Example: 172.31.0.0/31. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("tskbhtvkcxrywoqi")
    public suspend fun primaryIpv4Prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primaryIpv4Prefix = mapped
    }

    /**
     * @param value IPv6 Address Prefix of CE-PE interconnect links. Example: 3FFE:FFFF:0:CD30::a0/126. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("dcgyjwevanmrjgxl")
    public suspend fun primaryIpv6Prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primaryIpv6Prefix = mapped
    }

    /**
     * @param value Secondary IPv4 Address Prefix of CE-PE interconnect links. Example: 172.31.0.20/31. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("xgodtgawevuygbfo")
    public suspend fun secondaryIpv4Prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondaryIpv4Prefix = mapped
    }

    /**
     * @param value Secondary IPv6 Address Prefix of CE-PE interconnect links. Example: 3FFE:FFFF:0:CD30::a4/126. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("ewntrtcehopmtcsg")
    public suspend fun secondaryIpv6Prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondaryIpv6Prefix = mapped
    }

    /**
     * @param value Vlan identifier. Example : 501
     */
    @JvmName("ajxdikwiqgocsexm")
    public suspend fun vlanId(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vlanId = mapped
    }

    internal fun build(): ExternalNetworkPropertiesOptionAPropertiesArgs =
        ExternalNetworkPropertiesOptionAPropertiesArgs(
            mtu = mtu,
            peerASN = peerASN ?: throw PulumiNullFieldException("peerASN"),
            primaryIpv4Prefix = primaryIpv4Prefix,
            primaryIpv6Prefix = primaryIpv6Prefix,
            secondaryIpv4Prefix = secondaryIpv4Prefix,
            secondaryIpv6Prefix = secondaryIpv6Prefix,
            vlanId = vlanId ?: throw PulumiNullFieldException("vlanId"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/ExternalNetworkPropertiesOptionAPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.ExternalNetworkPropertiesOptionAPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * option A properties object
 * @property mtu MTU to use for option A peering.
 * @property peerASN Peer ASN number.Example : 28
 * @property primaryIpv4Prefix IPv4 Address Prefix of CE-PE interconnect links. Example: 172.31.0.0/31. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
 * @property primaryIpv6Prefix IPv6 Address Prefix of CE-PE interconnect links. Example: 3FFE:FFFF:0:CD30::a0/126. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
 * @property secondaryIpv4Prefix Secondary IPv4 Address Prefix of CE-PE interconnect links. Example: 172.31.0.20/31. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
 * @property secondaryIpv6Prefix Secondary IPv6 Address Prefix of CE-PE interconnect links. Example: 3FFE:FFFF:0:CD30::a4/126. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
 * @property vlanId Vlan identifier. Example : 501
 */
public data class ExternalNetworkPropertiesOptionAPropertiesArgs(
    public val mtu: Output<Int>? = null,
    public val peerASN: Output<Int>,
    public val primaryIpv4Prefix: Output<String>? = null,
    public val primaryIpv6Prefix: Output<String>? = null,
    public val secondaryIpv4Prefix: Output<String>? = null,
    public val secondaryIpv6Prefix: Output<String>? = null,
    public val vlanId: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.ExternalNetworkPropertiesOptionAPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.ExternalNetworkPropertiesOptionAPropertiesArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.ExternalNetworkPropertiesOptionAPropertiesArgs.builder()
            .mtu(mtu?.applyValue({ args0 -> args0 }))
            .peerASN(peerASN.applyValue({ args0 -> args0 }))
            .primaryIpv4Prefix(primaryIpv4Prefix?.applyValue({ args0 -> args0 }))
            .primaryIpv6Prefix(primaryIpv6Prefix?.applyValue({ args0 -> args0 }))
            .secondaryIpv4Prefix(secondaryIpv4Prefix?.applyValue({ args0 -> args0 }))
            .secondaryIpv6Prefix(secondaryIpv6Prefix?.applyValue({ args0 -> args0 }))
            .vlanId(vlanId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExternalNetworkPropertiesOptionAPropertiesArgs].
 */
@PulumiTagMarker
public class ExternalNetworkPropertiesOptionAPropertiesArgsBuilder internal constructor() {
    private var mtu: Output<Int>? = null

    private var peerASN: Output<Int>? = null

    private var primaryIpv4Prefix: Output<String>? = null

    private var primaryIpv6Prefix: Output<String>? = null

    private var secondaryIpv4Prefix: Output<String>? = null

    private var secondaryIpv6Prefix: Output<String>? = null

    private var vlanId: Output<Int>? = null

    /**
     * @param value MTU to use for option A peering.
     */
    @JvmName("tigrgdtxrqwismhi")
    public suspend fun mtu(`value`: Output<Int>) {
        this.mtu = value
    }

    /**
     * @param value Peer ASN number.Example : 28
     */
    @JvmName("daccymgiqljifqrr")
    public suspend fun peerASN(`value`: Output<Int>) {
        this.peerASN = value
    }

    /**
     * @param value IPv4 Address Prefix of CE-PE interconnect links. Example: 172.31.0.0/31. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("jjopaufpixmqigvx")
    public suspend fun primaryIpv4Prefix(`value`: Output<String>) {
        this.primaryIpv4Prefix = value
    }

    /**
     * @param value IPv6 Address Prefix of CE-PE interconnect links. Example: 3FFE:FFFF:0:CD30::a0/126. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("uaasjskpwypuuxwu")
    public suspend fun primaryIpv6Prefix(`value`: Output<String>) {
        this.primaryIpv6Prefix = value
    }

    /**
     * @param value Secondary IPv4 Address Prefix of CE-PE interconnect links. Example: 172.31.0.20/31. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("lamywxryoaexttae")
    public suspend fun secondaryIpv4Prefix(`value`: Output<String>) {
        this.secondaryIpv4Prefix = value
    }

    /**
     * @param value Secondary IPv6 Address Prefix of CE-PE interconnect links. Example: 3FFE:FFFF:0:CD30::a4/126. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("clsdkcycnpevexdb")
    public suspend fun secondaryIpv6Prefix(`value`: Output<String>) {
        this.secondaryIpv6Prefix = value
    }

    /**
     * @param value Vlan identifier. Example : 501
     */
    @JvmName("gyogspexdxmlunnj")
    public suspend fun vlanId(`value`: Output<Int>) {
        this.vlanId = value
    }

    /**
     * @param value MTU to use for option A peering.
     */
    @JvmName("afpmaexdtpmbuoqg")
    public suspend fun mtu(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mtu = mapped
    }

    /**
     * @param value Peer ASN number.Example : 28
     */
    @JvmName("eqvitrsvvshrygav")
    public suspend fun peerASN(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.peerASN = mapped
    }

    /**
     * @param value IPv4 Address Prefix of CE-PE interconnect links. Example: 172.31.0.0/31. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("qoudjavtqnguijal")
    public suspend fun primaryIpv4Prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primaryIpv4Prefix = mapped
    }

    /**
     * @param value IPv6 Address Prefix of CE-PE interconnect links. Example: 3FFE:FFFF:0:CD30::a0/126. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("rocmjfhtrpwcbrmj")
    public suspend fun primaryIpv6Prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primaryIpv6Prefix = mapped
    }

    /**
     * @param value Secondary IPv4 Address Prefix of CE-PE interconnect links. Example: 172.31.0.20/31. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("vuepxndnfhsbyhvg")
    public suspend fun secondaryIpv4Prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondaryIpv4Prefix = mapped
    }

    /**
     * @param value Secondary IPv6 Address Prefix of CE-PE interconnect links. Example: 3FFE:FFFF:0:CD30::a4/126. The values can be specified at the time of creation or can be updated afterwards. Any update to the values post-provisioning may disrupt traffic. The 1st and 3rd IPs are to be configured on CE1 and CE2 for Option B interfaces. The 2nd and 4th IPs are to be configured on PE1 and PE2 for Option B interfaces.
     */
    @JvmName("aqckokuddrsxpdho")
    public suspend fun secondaryIpv6Prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondaryIpv6Prefix = mapped
    }

    /**
     * @param value Vlan identifier. Example : 501
     */
    @JvmName("msvgnlnrxerhviaw")
    public suspend fun vlanId(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vlanId = mapped
    }

    internal fun build(): ExternalNetworkPropertiesOptionAPropertiesArgs =
        ExternalNetworkPropertiesOptionAPropertiesArgs(
            mtu = mtu,
            peerASN = peerASN ?: throw PulumiNullFieldException("peerASN"),
            primaryIpv4Prefix = primaryIpv4Prefix,
            primaryIpv6Prefix = primaryIpv6Prefix,
            secondaryIpv4Prefix = secondaryIpv4Prefix,
            secondaryIpv6Prefix = secondaryIpv6Prefix,
            vlanId = vlanId ?: throw PulumiNullFieldException("vlanId"),
        )
}
